@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.service_usage_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -162,9 +173,9 @@ class ServiceUsageAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ServiceUsageTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the service usage client.
@@ -208,10 +219,10 @@ class ServiceUsageAsyncClient:
 
     async def enable_service(
         self,
-        request: Union[serviceusage.EnableServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.EnableServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Enable a service so that it can be used with a
@@ -219,6 +230,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_enable_service():
@@ -234,13 +252,13 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.EnableServiceRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.EnableServiceRequest, dict]]):
                 The request object. Request message for the
                 `EnableService` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -297,10 +315,10 @@ class ServiceUsageAsyncClient:
 
     async def disable_service(
         self,
-        request: Union[serviceusage.DisableServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.DisableServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Disable a service so that it can no longer be used with a
@@ -314,6 +332,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_disable_service():
@@ -329,13 +354,13 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.DisableServiceRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.DisableServiceRequest, dict]]):
                 The request object. Request message for the
                 `DisableService` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -392,10 +417,10 @@ class ServiceUsageAsyncClient:
 
     async def get_service(
         self,
-        request: Union[serviceusage.GetServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.GetServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Service:
         r"""Returns the service configuration and enabled state
@@ -403,6 +428,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_get_service():
@@ -420,7 +452,7 @@ class ServiceUsageAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.GetServiceRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.GetServiceRequest, dict]]):
                 The request object. Request message for the `GetService`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -465,10 +497,10 @@ class ServiceUsageAsyncClient:
 
     async def list_services(
         self,
-        request: Union[serviceusage.ListServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.ListServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesAsyncPager:
         r"""List all services available to the specified project, and the
@@ -488,6 +520,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_list_services():
@@ -506,7 +545,7 @@ class ServiceUsageAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.ListServicesRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.ListServicesRequest, dict]]):
                 The request object. Request message for the
                 `ListServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -562,10 +601,10 @@ class ServiceUsageAsyncClient:
 
     async def batch_enable_services(
         self,
-        request: Union[serviceusage.BatchEnableServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.BatchEnableServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Enable multiple services on a project. The operation is atomic:
@@ -575,6 +614,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_batch_enable_services():
@@ -590,13 +636,13 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.BatchEnableServicesRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.BatchEnableServicesRequest, dict]]):
                 The request object. Request message for the
                 `BatchEnableServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -653,10 +699,10 @@ class ServiceUsageAsyncClient:
 
     async def batch_get_services(
         self,
-        request: Union[serviceusage.BatchGetServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.BatchGetServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> serviceusage.BatchGetServicesResponse:
         r"""Returns the service configurations and enabled states
@@ -664,6 +710,13 @@ class ServiceUsageAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             async def sample_batch_get_services():
@@ -681,7 +734,7 @@ class ServiceUsageAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.service_usage_v1.types.BatchGetServicesRequest, dict]):
+            request (Optional[Union[google.cloud.service_usage_v1.types.BatchGetServicesRequest, dict]]):
                 The request object. Request message for the
                 `BatchGetServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -729,14 +782,9 @@ class ServiceUsageAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-service-usage",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ServiceUsageAsyncClient",)
