@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.service_usage_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -59,7 +71,7 @@ class ServiceUsageClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[ServiceUsageTransport]:
         """Returns an appropriate transport class.
 
@@ -318,8 +330,8 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, ServiceUsageTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, ServiceUsageTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the service usage client.
@@ -333,7 +345,7 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
             transport (Union[str, ServiceUsageTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -363,6 +375,7 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -415,10 +428,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def enable_service(
         self,
-        request: Union[serviceusage.EnableServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.EnableServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Enable a service so that it can be used with a
@@ -426,6 +439,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_enable_service():
@@ -505,10 +525,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def disable_service(
         self,
-        request: Union[serviceusage.DisableServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.DisableServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Disable a service so that it can no longer be used with a
@@ -522,6 +542,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_disable_service():
@@ -601,10 +628,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def get_service(
         self,
-        request: Union[serviceusage.GetServiceRequest, dict] = None,
+        request: Optional[Union[serviceusage.GetServiceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Service:
         r"""Returns the service configuration and enabled state
@@ -612,6 +639,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_get_service():
@@ -675,10 +709,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def list_services(
         self,
-        request: Union[serviceusage.ListServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.ListServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesPager:
         r"""List all services available to the specified project, and the
@@ -698,6 +732,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_list_services():
@@ -773,10 +814,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def batch_enable_services(
         self,
-        request: Union[serviceusage.BatchEnableServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.BatchEnableServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Enable multiple services on a project. The operation is atomic:
@@ -786,6 +827,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_batch_enable_services():
@@ -865,10 +913,10 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
     def batch_get_services(
         self,
-        request: Union[serviceusage.BatchGetServicesRequest, dict] = None,
+        request: Optional[Union[serviceusage.BatchGetServicesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> serviceusage.BatchGetServicesResponse:
         r"""Returns the service configurations and enabled states
@@ -876,6 +924,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import service_usage_v1
 
             def sample_batch_get_services():
@@ -949,14 +1004,9 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-service-usage",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ServiceUsageClient",)
