@@ -13,12 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .resources import (
-    OperationMetadata,
-    Service,
-    ServiceConfig,
-    State,
-)
+from .resources import OperationMetadata, Service, ServiceConfig, State
 from .serviceusage import (
     BatchEnableServicesRequest,
     BatchEnableServicesResponse,
